@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2020 The Project Lombok Authors.
+ * Copyright (C) 2015-2021 The Project Lombok Authors.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -44,6 +44,7 @@ import org.eclipse.jdt.internal.compiler.ast.FieldReference;
 import org.eclipse.jdt.internal.compiler.ast.IfStatement;
 import org.eclipse.jdt.internal.compiler.ast.IntLiteral;
 import org.eclipse.jdt.internal.compiler.ast.MessageSend;
+import org.eclipse.jdt.internal.compiler.ast.MethodDeclaration;
 import org.eclipse.jdt.internal.compiler.ast.NullLiteral;
 import org.eclipse.jdt.internal.compiler.ast.OperatorIds;
 import org.eclipse.jdt.internal.compiler.ast.ParameterizedQualifiedTypeReference;
@@ -68,6 +69,7 @@ import lombok.core.SpiLoadUtil;
 import lombok.core.TypeLibrary;
 import lombok.core.configuration.CheckerFrameworkVersion;
 import lombok.eclipse.EclipseNode;
+import lombok.eclipse.handlers.HandleBuilder.BuilderJob;
 
 public class EclipseSingularsRecipes {
 	public interface TypeReferenceMaker {
@@ -258,20 +260,20 @@ public class EclipseSingularsRecipes {
 		 * If you need more control over the return type and value, use
 		 * {@link #generateMethods(SingularData, boolean, EclipseNode, boolean, TypeReferenceMaker, StatementMaker)}.
 		 */
-		public void generateMethods(CheckerFrameworkVersion cfv, SingularData data, boolean deprecate, final EclipseNode builderType, boolean fluent, final boolean chain, AccessLevel access) {
+		public void generateMethods(final BuilderJob job, SingularData data, boolean deprecate) {
 			TypeReferenceMaker returnTypeMaker = new TypeReferenceMaker() {
 				@Override public TypeReference make() {
-					return chain ? cloneSelfType(builderType) : TypeReference.baseTypeReference(TypeIds.T_void, 0);
+					return job.oldChain ? cloneSelfType(job.builderType) : TypeReference.baseTypeReference(TypeIds.T_void, 0);
 				}
 			};
 			
 			StatementMaker returnStatementMaker = new StatementMaker() {
 				@Override public ReturnStatement make() {
-					return chain ? new ReturnStatement(new ThisReference(0, 0), 0, 0) : null;
+					return job.oldChain ? new ReturnStatement(new ThisReference(0, 0), 0, 0) : null;
 				}
 			};
 			
-			generateMethods(cfv, data, deprecate, builderType, fluent, returnTypeMaker, returnStatementMaker, access);
+			generateMethods(job.checkerFramework, data, deprecate, job.builderType, job.oldFluent, returnTypeMaker, returnStatementMaker, job.accessInners);
 		}
 		
 		/**
@@ -299,13 +301,10 @@ public class EclipseSingularsRecipes {
 		
 		// -- Utility methods --
 		
-		protected Annotation[] generateSelfReturnAnnotations(boolean deprecate, CheckerFrameworkVersion cfv, ASTNode source) {
+		protected Annotation[] generateSelfReturnAnnotations(boolean deprecate, ASTNode source) {
 			Annotation deprecated = deprecate ? generateDeprecatedAnnotation(source) : null;
-			Annotation returnsReceiver = cfv.generateReturnsReceiver() ? generateNamedAnnotation(source, CheckerFrameworkVersion.NAME__RETURNS_RECEIVER) : null;
-			if (deprecated == null && returnsReceiver == null) return null;
-			if (deprecated == null) return new Annotation[] {returnsReceiver};
-			if (returnsReceiver == null) return new Annotation[] {deprecated};
-			return new Annotation[] {deprecated, returnsReceiver};
+			if (deprecated == null) return null;
+			return new Annotation[] {deprecated};
 		}
 		
 		/**
@@ -432,7 +431,7 @@ public class EclipseSingularsRecipes {
 			}
 		}
 		
-		protected void nullBehaviorize(EclipseNode typeNode, SingularData data, List<Statement> statements, Argument arg) {
+		protected void nullBehaviorize(EclipseNode typeNode, SingularData data, List<Statement> statements, Argument arg, MethodDeclaration md) {
 			boolean ignoreNullCollections = data.isIgnoreNullCollections();
 			
 			if (ignoreNullCollections) {
@@ -441,16 +440,26 @@ public class EclipseSingularsRecipes {
 				b.statements = statements.toArray(new Statement[statements.size()]);
 				statements.clear();
 				statements.add(new IfStatement(isNotNull, b, 0, 0));
-				EclipseHandlerUtil.createRelevantNullableAnnotation(typeNode, arg);
+				EclipseHandlerUtil.createRelevantNullableAnnotation(typeNode, arg, md);
 				return;
 			}
 			
-			EclipseHandlerUtil.createRelevantNonNullAnnotation(typeNode, arg);
+			EclipseHandlerUtil.createRelevantNonNullAnnotation(typeNode, arg, md);
 			Statement nullCheck = EclipseHandlerUtil.generateNullCheck(null, data.getPluralName(), typeNode, "%s cannot be null");
 			statements.add(0, nullCheck);
 		}
 		
+		protected abstract int getTypeArgumentsCount();
+		
 		protected abstract char[][] getEmptyMakerReceiver(String targetFqn);
 		protected abstract char[] getEmptyMakerSelector(String targetFqn);
+		
+		public MessageSend getEmptyExpression(String targetFqn, SingularData data, EclipseNode typeNode, ASTNode source) {
+			MessageSend send = new MessageSend();
+			send.receiver = generateQualifiedNameRef(source, getEmptyMakerReceiver(targetFqn));
+			send.selector = getEmptyMakerSelector(targetFqn);
+			send.typeArguments = createTypeArgs(getTypeArgumentsCount(), false, typeNode, data.getTypeArgs());
+			return send;
+		}
 	}
 }
