@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2021 The Project Lombok Authors.
+ * Copyright (C) 2010-2024 The Project Lombok Authors.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -22,7 +22,7 @@
 package lombok.eclipse.handlers;
 
 import static lombok.core.handlers.HandlerUtil.*;
-import static lombok.eclipse.Eclipse.*;
+import static lombok.eclipse.Eclipse.ECLIPSE_DO_NOT_TOUCH_FLAG;
 import static lombok.eclipse.handlers.EclipseHandlerUtil.*;
 
 import java.lang.reflect.Modifier;
@@ -101,6 +101,9 @@ public class HandleConstructor {
 			boolean force = ann.force();
 			
 			List<Annotation> onConstructor = unboxAndRemoveAnnotationParameter(ast, "onConstructor", "@NoArgsConstructor(onConstructor", annotationNode);
+			if (!onConstructor.isEmpty()) {
+				handleFlagUsage(annotationNode, ConfigurationKeys.ON_X_FLAG_USAGE, "@NoArgsConstructor(onConstructor=...)");
+			}
 			
 			handleConstructor.generateConstructor(typeNode, level, Collections.<EclipseNode>emptyList(), force, staticName, SkipIfConstructorExists.NO, onConstructor, annotationNode);
 		}
@@ -125,6 +128,9 @@ public class HandleConstructor {
 			}
 			
 			List<Annotation> onConstructor = unboxAndRemoveAnnotationParameter(ast, "onConstructor", "@RequiredArgsConstructor(onConstructor", annotationNode);
+			if (!onConstructor.isEmpty()) {
+				handleFlagUsage(annotationNode, ConfigurationKeys.ON_X_FLAG_USAGE, "@RequiredArgsConstructor(onConstructor=...)");
+			}
 			
 			handleConstructor.generateConstructor(
 				typeNode, level, findRequiredFields(typeNode), false, staticName, SkipIfConstructorExists.NO,
@@ -132,6 +138,36 @@ public class HandleConstructor {
 		}
 	}
 	
+	@Provides
+	public static class HandleAllArgsConstructor extends EclipseAnnotationHandler<AllArgsConstructor> {
+		private static final String NAME = AllArgsConstructor.class.getSimpleName();
+
+		private HandleConstructor handleConstructor = new HandleConstructor();
+		
+		@Override public void handle(AnnotationValues<AllArgsConstructor> annotation, Annotation ast, EclipseNode annotationNode) {
+			handleFlagUsage(annotationNode, ConfigurationKeys.ALL_ARGS_CONSTRUCTOR_FLAG_USAGE, "@AllArgsConstructor", ConfigurationKeys.ANY_CONSTRUCTOR_FLAG_USAGE, "any @xArgsConstructor");
+			
+			EclipseNode typeNode = annotationNode.up();
+			if (!checkLegality(typeNode, annotationNode, NAME)) return;
+			AllArgsConstructor ann = annotation.getInstance();
+			AccessLevel level = ann.access();
+			if (level == AccessLevel.NONE) return;
+			String staticName = ann.staticName();
+			if (annotation.isExplicit("suppressConstructorProperties")) {
+				annotationNode.addError("This deprecated feature is no longer supported. Remove it; you can create a lombok.config file with 'lombok.anyConstructor.suppressConstructorProperties = true'.");
+			}
+			
+			List<Annotation> onConstructor = unboxAndRemoveAnnotationParameter(ast, "onConstructor", "@AllArgsConstructor(onConstructor", annotationNode);
+			if (!onConstructor.isEmpty()) {
+				handleFlagUsage(annotationNode, ConfigurationKeys.ON_X_FLAG_USAGE, "@AllArgsConstructor(onConstructor=...)");
+			}
+			
+			handleConstructor.generateConstructor(
+				typeNode, level, findAllFields(typeNode), false, staticName, SkipIfConstructorExists.NO,
+				onConstructor, annotationNode);
+		}
+	}
+	
 	private static List<EclipseNode> findRequiredFields(EclipseNode typeNode) {
 		return findFields(typeNode, true);
 	}
@@ -167,33 +203,6 @@ public class HandleConstructor {
 		return fields;
 	}
 	
-	@Provides
-	public static class HandleAllArgsConstructor extends EclipseAnnotationHandler<AllArgsConstructor> {
-		private static final String NAME = AllArgsConstructor.class.getSimpleName();
-
-		private HandleConstructor handleConstructor = new HandleConstructor();
-		
-		@Override public void handle(AnnotationValues<AllArgsConstructor> annotation, Annotation ast, EclipseNode annotationNode) {
-			handleFlagUsage(annotationNode, ConfigurationKeys.ALL_ARGS_CONSTRUCTOR_FLAG_USAGE, "@AllArgsConstructor", ConfigurationKeys.ANY_CONSTRUCTOR_FLAG_USAGE, "any @xArgsConstructor");
-			
-			EclipseNode typeNode = annotationNode.up();
-			if (!checkLegality(typeNode, annotationNode, NAME)) return;
-			AllArgsConstructor ann = annotation.getInstance();
-			AccessLevel level = ann.access();
-			if (level == AccessLevel.NONE) return;
-			String staticName = ann.staticName();
-			if (annotation.isExplicit("suppressConstructorProperties")) {
-				annotationNode.addError("This deprecated feature is no longer supported. Remove it; you can create a lombok.config file with 'lombok.anyConstructor.suppressConstructorProperties = true'.");
-			}
-			
-			List<Annotation> onConstructor = unboxAndRemoveAnnotationParameter(ast, "onConstructor", "@AllArgsConstructor(onConstructor", annotationNode);
-			
-			handleConstructor.generateConstructor(
-				typeNode, level, findAllFields(typeNode), false, staticName, SkipIfConstructorExists.NO,
-				onConstructor, annotationNode);
-		}
-	}
-	
 	static boolean checkLegality(EclipseNode typeNode, EclipseNode errorNode, String name) {
 		if (!isClassOrEnum(typeNode)) {
 			errorNode.addError(name + " is only supported on a class or an enum.");
@@ -277,7 +286,8 @@ public class HandleConstructor {
 			ConstructorDeclaration constr = createConstructor(
 				staticConstrRequired ? AccessLevel.PRIVATE : level, typeNode, fieldsToParam, forceDefaults,
 				sourceNode, onConstructor);
-			injectMethod(typeNode, constr);
+			EclipseNode constructorNode = injectMethod(typeNode, constr);
+			generateConstructorJavadoc(typeNode, constructorNode, fieldsToParam);
 		}
 		generateStaticConstructor(staticConstrRequired, typeNode, staticName, level, fieldsToParam, source);
 	}
@@ -285,7 +295,8 @@ public class HandleConstructor {
 	private void generateStaticConstructor(boolean staticConstrRequired, EclipseNode typeNode, String staticName, AccessLevel level, Collection<EclipseNode> fields, ASTNode source) {
 		if (staticConstrRequired) {
 			MethodDeclaration staticConstr = createStaticConstructor(level, staticName, typeNode, fields, source);
-			injectMethod(typeNode, staticConstr);
+			EclipseNode constructorNode = injectMethod(typeNode, staticConstr);
+			generateConstructorJavadoc(typeNode, constructorNode, fields);
 		}
 	}
 	
@@ -575,4 +586,27 @@ public class HandleConstructor {
 		constructor.traverse(new SetGeneratedByVisitor(source), typeDecl.scope);
 		return constructor;
 	}
+	
+	private void generateConstructorJavadoc(EclipseNode typeNode, EclipseNode constructorNode, Collection<EclipseNode> fields) {
+		if (fields.isEmpty()) return;
+		
+		String constructorJavadoc = getConstructorJavadocHeader(typeNode.getName());
+		boolean fieldDescriptionAdded = false;
+		for (EclipseNode fieldNode : fields) {
+			String paramName = String.valueOf(removePrefixFromField(fieldNode));
+			String fieldJavadoc = getDocComment(fieldNode);
+			String paramJavadoc = getConstructorParameterJavadoc(paramName, fieldJavadoc);
+			
+			if (paramJavadoc == null) {
+				paramJavadoc = "@param " + paramName;
+			} else {
+				fieldDescriptionAdded = true;
+			}
+			
+			constructorJavadoc = addJavadocLine(constructorJavadoc, paramJavadoc);
+		}
+		if (fieldDescriptionAdded) {
+			setDocComment(typeNode, constructorNode, constructorJavadoc);
+		}
+	}
 }
