@@ -35,6 +35,7 @@ import lombok.installer.OsUtils;
 public class StandardProductDescriptor implements EclipseProductDescriptor {
 	
 	private static final String USER_HOME = System.getProperty("user.home", ".");
+	private static final String[] BASE_WINDOWS_ROOTS = {"\\", "\\Program Files", "\\Program Files (x86)", "\\ProgramData\\Chocolatey\\lib"};
 	private static final String[] WINDOWS_ROOTS = windowsRoots();
 	private static final String[] MAC_ROOTS = {"/Applications", USER_HOME};
 	private static final String[] UNIX_ROOTS = {USER_HOME};
@@ -159,8 +160,11 @@ public class StandardProductDescriptor implements EclipseProductDescriptor {
 	
 	private static String[] windowsRoots() {
 		String localAppData = windowsLocalAppData();
-		if (localAppData == null) return new String[] {"\\", "\\Program Files", "\\Program Files (x86)", USER_HOME};
-		return new String[] {"\\", "\\Program Files", "\\Program Files (x86)", USER_HOME, localAppData};
+		String[] out = new String[BASE_WINDOWS_ROOTS.length + (localAppData == null ? 1 : 2)];
+		System.arraycopy(BASE_WINDOWS_ROOTS, 0, out, 0, BASE_WINDOWS_ROOTS.length);
+		out[BASE_WINDOWS_ROOTS.length] = USER_HOME;
+		if (localAppData != null) out[BASE_WINDOWS_ROOTS.length + 1] = localAppData;
+		return out;
 	}
 	
 	private static String windowsLocalAppData() {
