@@ -1,12 +1,10 @@
 package org.checkerframework.common.returnsreceiver.qual;
 
 import java.lang.annotation.ElementType;
-import java.lang.annotation.Inherited;
 import java.lang.annotation.Retention;
 import java.lang.annotation.RetentionPolicy;
 import java.lang.annotation.Target;
 
 @Retention(RetentionPolicy.RUNTIME)
-@Target(ElementType.METHOD)
-@Inherited
+@Target({ElementType.TYPE_USE, ElementType.TYPE_PARAMETER})
 public @interface This {}
\ No newline at end of file
