@@ -1,8 +1,8 @@
-//version :8
 class GeneratedOffJavaxOn {
 	int x;
 	@java.lang.SuppressWarnings("all")
 	@javax.annotation.Generated("lombok")
+	@lombok.Generated
 	public int getX() {
 		return this.x;
 	}
