@@ -1,6 +1,8 @@
+// version 16:
 class LoggerFloggerRecord {
-	record Inner(String x) {
+	public record Inner(String x) {
 		@java.lang.SuppressWarnings("all")
+		@lombok.Generated
 		private static final com.google.common.flogger.FluentLogger log = com.google.common.flogger.FluentLogger.forEnclosingClass();
 	}
-}
\ No newline at end of file
+}
