@@ -1,22 +1,21 @@
 import java.util.List;
 import java.util.Collection;
-
 import lombok.Singular;
 @lombok.Builder class BuilderSingularLists<T> {
-  public static @java.lang.SuppressWarnings("all") class BuilderSingularListsBuilder<T> {
-    private @java.lang.SuppressWarnings("all") java.util.ArrayList<T> children;
-    private @java.lang.SuppressWarnings("all") java.util.ArrayList<Number> scarves;
-    private @java.lang.SuppressWarnings("all") java.util.ArrayList<java.lang.Object> rawList;
-    @java.lang.SuppressWarnings("all") BuilderSingularListsBuilder() {
+  public static @java.lang.SuppressWarnings("all") @lombok.Generated class BuilderSingularListsBuilder<T> {
+    private @java.lang.SuppressWarnings("all") @lombok.Generated java.util.ArrayList<T> children;
+    private @java.lang.SuppressWarnings("all") @lombok.Generated java.util.ArrayList<Number> scarves;
+    private @java.lang.SuppressWarnings("all") @lombok.Generated java.util.ArrayList<java.lang.Object> rawList;
+    @java.lang.SuppressWarnings("all") @lombok.Generated BuilderSingularListsBuilder() {
       super();
     }
-    public @java.lang.SuppressWarnings("all") BuilderSingularLists.BuilderSingularListsBuilder<T> child(final T child) {
+    public @java.lang.SuppressWarnings("all") @lombok.Generated BuilderSingularLists.BuilderSingularListsBuilder<T> child(final T child) {
       if ((this.children == null))
           this.children = new java.util.ArrayList<T>();
       this.children.add(child);
       return this;
     }
-    public @java.lang.SuppressWarnings("all") BuilderSingularLists.BuilderSingularListsBuilder<T> children(final java.util.Collection<? extends T> children) {
+    public @java.lang.SuppressWarnings("all") @lombok.Generated BuilderSingularLists.BuilderSingularListsBuilder<T> children(final java.util.Collection<? extends T> children) {
       if ((children == null))
           {
             throw new java.lang.NullPointerException("children cannot be null");
@@ -26,18 +25,18 @@ import lombok.Singular;
       this.children.addAll(children);
       return this;
     }
-    public @java.lang.SuppressWarnings("all") BuilderSingularLists.BuilderSingularListsBuilder<T> clearChildren() {
+    public @java.lang.SuppressWarnings("all") @lombok.Generated BuilderSingularLists.BuilderSingularListsBuilder<T> clearChildren() {
       if ((this.children != null))
           this.children.clear();
       return this;
     }
-    public @java.lang.SuppressWarnings("all") BuilderSingularLists.BuilderSingularListsBuilder<T> scarf(final Number scarf) {
+    public @java.lang.SuppressWarnings("all") @lombok.Generated BuilderSingularLists.BuilderSingularListsBuilder<T> scarf(final Number scarf) {
       if ((this.scarves == null))
           this.scarves = new java.util.ArrayList<Number>();
       this.scarves.add(scarf);
       return this;
     }
-    public @java.lang.SuppressWarnings("all") BuilderSingularLists.BuilderSingularListsBuilder<T> scarves(final java.util.Collection<? extends Number> scarves) {
+    public @java.lang.SuppressWarnings("all") @lombok.Generated BuilderSingularLists.BuilderSingularListsBuilder<T> scarves(final java.util.Collection<? extends Number> scarves) {
       if ((scarves == null))
           {
             throw new java.lang.NullPointerException("scarves cannot be null");
@@ -47,18 +46,18 @@ import lombok.Singular;
       this.scarves.addAll(scarves);
       return this;
     }
-    public @java.lang.SuppressWarnings("all") BuilderSingularLists.BuilderSingularListsBuilder<T> clearScarves() {
+    public @java.lang.SuppressWarnings("all") @lombok.Generated BuilderSingularLists.BuilderSingularListsBuilder<T> clearScarves() {
       if ((this.scarves != null))
           this.scarves.clear();
       return this;
     }
-    public @java.lang.SuppressWarnings("all") BuilderSingularLists.BuilderSingularListsBuilder<T> rawList(final java.lang.Object rawList) {
+    public @java.lang.SuppressWarnings("all") @lombok.Generated BuilderSingularLists.BuilderSingularListsBuilder<T> rawList(final java.lang.Object rawList) {
       if ((this.rawList == null))
           this.rawList = new java.util.ArrayList<java.lang.Object>();
       this.rawList.add(rawList);
       return this;
     }
-    public @java.lang.SuppressWarnings("all") BuilderSingularLists.BuilderSingularListsBuilder<T> rawList(final java.util.Collection<?> rawList) {
+    public @java.lang.SuppressWarnings("all") @lombok.Generated BuilderSingularLists.BuilderSingularListsBuilder<T> rawList(final java.util.Collection<?> rawList) {
       if ((rawList == null))
           {
             throw new java.lang.NullPointerException("rawList cannot be null");
@@ -68,12 +67,12 @@ import lombok.Singular;
       this.rawList.addAll(rawList);
       return this;
     }
-    public @java.lang.SuppressWarnings("all") BuilderSingularLists.BuilderSingularListsBuilder<T> clearRawList() {
+    public @java.lang.SuppressWarnings("all") @lombok.Generated BuilderSingularLists.BuilderSingularListsBuilder<T> clearRawList() {
       if ((this.rawList != null))
           this.rawList.clear();
       return this;
     }
-    public @java.lang.SuppressWarnings("all") BuilderSingularLists<T> build() {
+    public @java.lang.SuppressWarnings("all") @lombok.Generated BuilderSingularLists<T> build() {
       java.util.List<T> children;
       switch (((this.children == null) ? 0 : this.children.size())) {
       case 0 :
@@ -109,20 +108,20 @@ import lombok.Singular;
       }
       return new BuilderSingularLists<T>(children, scarves, rawList);
     }
-    public @java.lang.Override @java.lang.SuppressWarnings("all") java.lang.String toString() {
+    public @java.lang.Override @java.lang.SuppressWarnings("all") @lombok.Generated java.lang.String toString() {
       return (((((("BuilderSingularLists.BuilderSingularListsBuilder(children=" + this.children) + ", scarves=") + this.scarves) + ", rawList=") + this.rawList) + ")");
     }
   }
   private @Singular List<T> children;
   private @Singular Collection<? extends Number> scarves;
   private @SuppressWarnings("all") @Singular("rawList") List rawList;
-  @java.lang.SuppressWarnings("all") BuilderSingularLists(final List<T> children, final Collection<? extends Number> scarves, final List rawList) {
+  @java.lang.SuppressWarnings("all") @lombok.Generated BuilderSingularLists(final List<T> children, final Collection<? extends Number> scarves, final List rawList) {
     super();
     this.children = children;
     this.scarves = scarves;
     this.rawList = rawList;
   }
-  public static @java.lang.SuppressWarnings("all") <T>BuilderSingularLists.BuilderSingularListsBuilder<T> builder() {
+  public static @java.lang.SuppressWarnings("all") @lombok.Generated <T>BuilderSingularLists.BuilderSingularListsBuilder<T> builder() {
     return new BuilderSingularLists.BuilderSingularListsBuilder<T>();
   }
-}
\ No newline at end of file
+}
