@@ -5,9 +5,4 @@ import lombok.RequiredArgsConstructor;
 public @AllArgsConstructor @RequiredArgsConstructor @NoArgsConstructor record ConstructorsOnRecord(String a, String b) {
 /* Implicit */  private final String a;
 /* Implicit */  private final String b;
-  public ConstructorsOnRecord(String a, String b) {
-    super();
-    .a = a;
-    .b = b;
-  }
 }
