@@ -2,13 +2,13 @@
   private int x;
   private int y;
   private final String z;
-  public @java.lang.SuppressWarnings("all") void setX(final int x) {
+  public @java.lang.SuppressWarnings("all") @lombok.Generated void setX(final int x) {
     this.x = x;
   }
-  public @java.lang.SuppressWarnings("all") void setY(final int y) {
+  public @java.lang.SuppressWarnings("all") @lombok.Generated void setY(final int y) {
     this.y = y;
   }
-  public @java.lang.Override @java.lang.SuppressWarnings("all") boolean equals(final java.lang.Object o) {
+  public @java.lang.Override @java.lang.SuppressWarnings("all") @lombok.Generated boolean equals(final java.lang.Object o) {
     if ((o == this))
         return true;
     if ((! (o instanceof DataWithGetter)))
@@ -26,10 +26,10 @@
         return false;
     return true;
   }
-  protected @java.lang.SuppressWarnings("all") boolean canEqual(final java.lang.Object other) {
+  protected @java.lang.SuppressWarnings("all") @lombok.Generated boolean canEqual(final java.lang.Object other) {
     return (other instanceof DataWithGetter);
   }
-  public @java.lang.Override @java.lang.SuppressWarnings("all") int hashCode() {
+  public @java.lang.Override @java.lang.SuppressWarnings("all") @lombok.Generated int hashCode() {
     final int PRIME = 59;
     int result = 1;
     result = ((result * PRIME) + this.getX());
@@ -38,20 +38,20 @@
     result = ((result * PRIME) + (($z == null) ? 43 : $z.hashCode()));
     return result;
   }
-  public @java.lang.Override @java.lang.SuppressWarnings("all") java.lang.String toString() {
+  public @java.lang.Override @java.lang.SuppressWarnings("all") @lombok.Generated java.lang.String toString() {
     return (((((("DataWithGetter(x=" + this.getX()) + ", y=") + this.getY()) + ", z=") + this.getZ()) + ")");
   }
-  public @java.lang.SuppressWarnings("all") DataWithGetter(final String z) {
+  public @java.lang.SuppressWarnings("all") @lombok.Generated DataWithGetter(final String z) {
     super();
     this.z = z;
   }
-  public @java.lang.SuppressWarnings("all") int getX() {
+  public @java.lang.SuppressWarnings("all") @lombok.Generated int getX() {
     return this.x;
   }
-  public @java.lang.SuppressWarnings("all") int getY() {
+  public @java.lang.SuppressWarnings("all") @lombok.Generated int getY() {
     return this.y;
   }
-  public @java.lang.SuppressWarnings("all") String getZ() {
+  public @java.lang.SuppressWarnings("all") @lombok.Generated String getZ() {
     return this.z;
   }
 }
