@@ -7,7 +7,7 @@ abstract class DelegateOnMethods {
     super();
   }
   public abstract @Delegate Bar getBar();
-  public @java.lang.SuppressWarnings("all") void bar(final java.util.ArrayList<java.lang.String> list) {
+  public @java.lang.SuppressWarnings("all") @lombok.Generated void bar(final java.util.ArrayList<java.lang.String> list) {
     this.getBar().bar(list);
   }
 }
