@@ -10,16 +10,16 @@ class DelegateWithVarargs {
   DelegateWithVarargs() {
     super();
   }
-  public @java.lang.SuppressWarnings("all") void array(final int[] array) {
+  public @java.lang.SuppressWarnings("all") @lombok.Generated void array(final int[] array) {
     this.bar.array(array);
   }
-  public @java.lang.SuppressWarnings("all") void arrayVarargs(final int[]... arrayVarargs) {
+  public @java.lang.SuppressWarnings("all") @lombok.Generated void arrayVarargs(final int[]... arrayVarargs) {
     this.bar.arrayVarargs(arrayVarargs);
   }
-  public @java.lang.SuppressWarnings("all") void justOneParameter(final int... varargs) {
+  public @java.lang.SuppressWarnings("all") @lombok.Generated void justOneParameter(final int... varargs) {
     this.bar.justOneParameter(varargs);
   }
-  public @java.lang.SuppressWarnings("all") void multipleParameters(final java.lang.String first, final int... varargs) {
+  public @java.lang.SuppressWarnings("all") @lombok.Generated void multipleParameters(final java.lang.String first, final int... varargs) {
     this.bar.multipleParameters(first, varargs);
   }
 }
