@@ -6,7 +6,7 @@ public class EqualsAndHashCodeInAnonymousClass {
       Inner() {
         super();
       }
-      public @java.lang.Override @java.lang.SuppressWarnings("all") boolean equals(final java.lang.Object o) {
+      public @java.lang.Override @java.lang.SuppressWarnings("all") @lombok.Generated boolean equals(final java.lang.Object o) {
         if ((o == this))
             return true;
         if ((! (o instanceof Inner)))
@@ -20,10 +20,10 @@ public class EqualsAndHashCodeInAnonymousClass {
             return false;
         return true;
       }
-      protected @java.lang.SuppressWarnings("all") boolean canEqual(final java.lang.Object other) {
+      protected @java.lang.SuppressWarnings("all") @lombok.Generated boolean canEqual(final java.lang.Object other) {
         return (other instanceof Inner);
       }
-      public @java.lang.Override @java.lang.SuppressWarnings("all") int hashCode() {
+      public @java.lang.Override @java.lang.SuppressWarnings("all") @lombok.Generated int hashCode() {
         final int PRIME = 59;
         int result = 1;
         final java.lang.Object $string = this.string;
