@@ -6,7 +6,7 @@ interface EqualsAndHashCodeNestedShadow {
       public Foo() {
         super();
       }
-      public @java.lang.Override @java.lang.SuppressWarnings("all") boolean equals(final java.lang.Object o) {
+      public @java.lang.Override @java.lang.SuppressWarnings("all") @lombok.Generated boolean equals(final java.lang.Object o) {
         if ((o == this))
             return true;
         if ((! (o instanceof EqualsAndHashCodeNestedShadow.Bar.Foo)))
@@ -16,10 +16,10 @@ interface EqualsAndHashCodeNestedShadow {
             return false;
         return true;
       }
-      protected @java.lang.SuppressWarnings("all") boolean canEqual(final java.lang.Object other) {
+      protected @java.lang.SuppressWarnings("all") @lombok.Generated boolean canEqual(final java.lang.Object other) {
         return (other instanceof EqualsAndHashCodeNestedShadow.Bar.Foo);
       }
-      public @java.lang.Override @java.lang.SuppressWarnings("all") int hashCode() {
+      public @java.lang.Override @java.lang.SuppressWarnings("all") @lombok.Generated int hashCode() {
         final int result = 1;
         return result;
       }
@@ -33,7 +33,7 @@ interface EqualsAndHashCodeNestedShadow {
       public Foo() {
         super();
       }
-      public @java.lang.Override @java.lang.SuppressWarnings("all") boolean equals(final java.lang.Object o) {
+      public @java.lang.Override @java.lang.SuppressWarnings("all") @lombok.Generated boolean equals(final java.lang.Object o) {
         if ((o == this))
             return true;
         if ((! (o instanceof EqualsAndHashCodeNestedShadow.Baz.Foo)))
@@ -43,10 +43,10 @@ interface EqualsAndHashCodeNestedShadow {
             return false;
         return true;
       }
-      protected @java.lang.SuppressWarnings("all") boolean canEqual(final java.lang.Object other) {
+      protected @java.lang.SuppressWarnings("all") @lombok.Generated boolean canEqual(final java.lang.Object other) {
         return (other instanceof EqualsAndHashCodeNestedShadow.Baz.Foo);
       }
-      public @java.lang.Override @java.lang.SuppressWarnings("all") int hashCode() {
+      public @java.lang.Override @java.lang.SuppressWarnings("all") @lombok.Generated int hashCode() {
         final int result = 1;
         return result;
       }
@@ -55,4 +55,4 @@ interface EqualsAndHashCodeNestedShadow {
       super();
     }
   }
-}
\ No newline at end of file
+}
