@@ -1,9 +1,9 @@
 public @lombok.experimental.FieldNameConstants class FieldNameConstantsConfigKeys {
-  public static final @java.lang.SuppressWarnings("all") class Foobar {
+  public static final @java.lang.SuppressWarnings("all") @lombok.Generated class Foobar {
     public static final java.lang.String iAmADvdPlayer = "iAmADvdPlayer";
     <clinit>() {
     }
-    private @java.lang.SuppressWarnings("all") Foobar() {
+    private @java.lang.SuppressWarnings("all") @lombok.Generated Foobar() {
       super();
     }
   }
@@ -11,4 +11,4 @@ public @lombok.experimental.FieldNameConstants class FieldNameConstantsConfigKey
   public FieldNameConstantsConfigKeys() {
     super();
   }
-}
\ No newline at end of file
+}
