@@ -2,12 +2,12 @@
 import lombok.experimental.FieldNameConstants;
 import lombok.AccessLevel;
 public @FieldNameConstants(level = AccessLevel.PACKAGE) record FieldNameConstantsOnRecord(String iAmADvdPlayer, int $skipMe, int andMe, String butPrintMePlease) {
-  static final @java.lang.SuppressWarnings("all") class Fields {
+  static final @java.lang.SuppressWarnings("all") @lombok.Generated class Fields {
     public static final java.lang.String iAmADvdPlayer = "iAmADvdPlayer";
     public static final java.lang.String butPrintMePlease = "butPrintMePlease";
     <clinit>() {
     }
-    private @java.lang.SuppressWarnings("all") Fields() {
+    private @java.lang.SuppressWarnings("all") @lombok.Generated Fields() {
       super();
     }
   }
@@ -18,11 +18,4 @@ public @FieldNameConstants(level = AccessLevel.PACKAGE) record FieldNameConstant
   static double skipMeToo;
   <clinit>() {
   }
-  public FieldNameConstantsOnRecord(String iAmADvdPlayer, int $skipMe,  int andMe, String butPrintMePlease) {
-    super();
-    .iAmADvdPlayer = iAmADvdPlayer;
-    .$skipMe = $skipMe;
-    .andMe = andMe;
-    .butPrintMePlease = butPrintMePlease;
-  }
 }
