@@ -3,7 +3,7 @@ class GeneratedOff {
   GeneratedOff() {
     super();
   }
-  public @java.lang.SuppressWarnings("all") int getX() {
+  public @java.lang.SuppressWarnings("all") @lombok.Generated int getX() {
     return this.x;
   }
 }
