@@ -6,22 +6,22 @@ public class GetterLazyInAnonymousClass {
       Inner() {
         super();
       }
-      public @java.lang.SuppressWarnings({"all", "unchecked"}) String getString() {
-        java.lang.Object value = this.string.get();
-        if ((value == null))
+      public @java.lang.SuppressWarnings({"all", "unchecked"}) @lombok.Generated String getString() {
+        java.lang.Object $value = this.string.get();
+        if (($value == null))
             {
               synchronized (this.string)
                 {
-                  value = this.string.get();
-                  if ((value == null))
+                  $value = this.string.get();
+                  if (($value == null))
                       {
                         final String actualValue = "test";
-                        value = ((actualValue == null) ? this.string : actualValue);
-                        this.string.set(value);
+                        $value = ((actualValue == null) ? this.string : actualValue);
+                        this.string.set($value);
                       }
                 }
             }
-        return (String) ((value == this.string) ? null : value);
+        return (String) (($value == this.string) ? null : $value);
       }
     }
     x() {
