@@ -4,10 +4,10 @@ class SetterWithJavaBeansSpecCapitalization {
   SetterWithJavaBeansSpecCapitalization() {
     super();
   }
-  public @java.lang.SuppressWarnings("all") void setA(final int a) {
+  public @java.lang.SuppressWarnings("all") @lombok.Generated void setA(final int a) {
     this.a = a;
   }
-  public @java.lang.SuppressWarnings("all") void setaField(final int aField) {
+  public @java.lang.SuppressWarnings("all") @lombok.Generated void setaField(final int aField) {
     this.aField = aField;
   }
-}
\ No newline at end of file
+}
