@@ -4,24 +4,24 @@ class SkipSuppressWarnings {
   SkipSuppressWarnings() {
     super();
   }
-  public String getField() {
+  public @lombok.Generated String getField() {
     return this.field;
   }
-  public @java.lang.SuppressWarnings({"unchecked"}) String getField2() {
-    java.lang.Object value = this.field2.get();
-    if ((value == null))
+  public @java.lang.SuppressWarnings({"unchecked"}) @lombok.Generated String getField2() {
+    java.lang.Object $value = this.field2.get();
+    if (($value == null))
         {
           synchronized (this.field2)
             {
-              value = this.field2.get();
-              if ((value == null))
+              $value = this.field2.get();
+              if (($value == null))
                   {
                     final String actualValue = "";
-                    value = ((actualValue == null) ? this.field2 : actualValue);
-                    this.field2.set(value);
+                    $value = ((actualValue == null) ? this.field2 : actualValue);
+                    this.field2.set($value);
                   }
             }
         }
-    return (String) ((value == this.field2) ? null : value);
+    return (String) (($value == this.field2) ? null : $value);
   }
-}
\ No newline at end of file
+}
