@@ -2,7 +2,7 @@ import java.util.List;
 public class SuperBuilderCustomized {
   public static @lombok.experimental.SuperBuilder class Parent {
     public static abstract class ParentBuilder<C extends Parent, B extends ParentBuilder<C, B>> {
-      private @java.lang.SuppressWarnings("all") int field1;
+      private @java.lang.SuppressWarnings("all") @lombok.Generated int field1;
       public ParentBuilder() {
         super();
       }
@@ -14,20 +14,20 @@ public class SuperBuilderCustomized {
         this.field1 = (field1 + 1);
         return self();
       }
-      protected abstract @java.lang.SuppressWarnings("all") B self();
-      public abstract @java.lang.SuppressWarnings("all") C build();
-      public @java.lang.Override @java.lang.SuppressWarnings("all") java.lang.String toString() {
+      protected abstract @java.lang.SuppressWarnings("all") @lombok.Generated B self();
+      public abstract @java.lang.SuppressWarnings("all") @lombok.Generated C build();
+      public @java.lang.Override @java.lang.SuppressWarnings("all") @lombok.Generated java.lang.String toString() {
         return (("SuperBuilderCustomized.Parent.ParentBuilder(field1=" + this.field1) + ")");
       }
     }
-    private static final @java.lang.SuppressWarnings("all") class ParentBuilderImpl extends SuperBuilderCustomized.Parent.ParentBuilder<SuperBuilderCustomized.Parent, SuperBuilderCustomized.Parent.ParentBuilderImpl> {
+    private static final @java.lang.SuppressWarnings("all") @lombok.Generated class ParentBuilderImpl extends SuperBuilderCustomized.Parent.ParentBuilder<SuperBuilderCustomized.Parent, SuperBuilderCustomized.Parent.ParentBuilderImpl> {
       private ParentBuilderImpl() {
         super();
       }
-      protected @java.lang.Override @java.lang.SuppressWarnings("all") SuperBuilderCustomized.Parent.ParentBuilderImpl self() {
+      protected @java.lang.Override @java.lang.SuppressWarnings("all") @lombok.Generated SuperBuilderCustomized.Parent.ParentBuilderImpl self() {
         return this;
       }
-      public @java.lang.Override @java.lang.SuppressWarnings("all") SuperBuilderCustomized.Parent build() {
+      public @java.lang.Override @java.lang.SuppressWarnings("all") @lombok.Generated SuperBuilderCustomized.Parent build() {
         return new SuperBuilderCustomized.Parent(this);
       }
     }
@@ -51,25 +51,25 @@ public class SuperBuilderCustomized {
         this.resetToDefault();
         return new Child(this);
       }
-      protected @java.lang.Override @java.lang.SuppressWarnings("all") SuperBuilderCustomized.Child.ChildBuilderImpl self() {
+      protected @java.lang.Override @java.lang.SuppressWarnings("all") @lombok.Generated SuperBuilderCustomized.Child.ChildBuilderImpl self() {
         return this;
       }
     }
-    public static abstract @java.lang.SuppressWarnings("all") class ChildBuilder<C extends SuperBuilderCustomized.Child, B extends SuperBuilderCustomized.Child.ChildBuilder<C, B>> extends Parent.ParentBuilder<C, B> {
-      private @java.lang.SuppressWarnings("all") double field2;
+    public static abstract @java.lang.SuppressWarnings("all") @lombok.Generated class ChildBuilder<C extends SuperBuilderCustomized.Child, B extends SuperBuilderCustomized.Child.ChildBuilder<C, B>> extends Parent.ParentBuilder<C, B> {
+      private @java.lang.SuppressWarnings("all") @lombok.Generated double field2;
       public ChildBuilder() {
         super();
       }
-      protected abstract @java.lang.Override @java.lang.SuppressWarnings("all") B self();
-      public abstract @java.lang.Override @java.lang.SuppressWarnings("all") C build();
       /**
        * @return {@code this}.
        */
-      public @java.lang.SuppressWarnings("all") B field2(final double field2) {
+      public @java.lang.SuppressWarnings("all") @lombok.Generated B field2(final double field2) {
         this.field2 = field2;
         return self();
       }
-      public @java.lang.Override @java.lang.SuppressWarnings("all") java.lang.String toString() {
+      protected abstract @java.lang.Override @java.lang.SuppressWarnings("all") @lombok.Generated B self();
+      public abstract @java.lang.Override @java.lang.SuppressWarnings("all") @lombok.Generated C build();
+      public @java.lang.Override @java.lang.SuppressWarnings("all") @lombok.Generated java.lang.String toString() {
         return (((("SuperBuilderCustomized.Child.ChildBuilder(super=" + super.toString()) + ", field2=") + this.field2) + ")");
       }
     }
@@ -77,7 +77,7 @@ public class SuperBuilderCustomized {
     public static ChildBuilder<?, ?> builder() {
       return new ChildBuilderImpl().field2(10.0);
     }
-    protected @java.lang.SuppressWarnings("all") Child(final SuperBuilderCustomized.Child.ChildBuilder<?, ?> b) {
+    protected @java.lang.SuppressWarnings("all") @lombok.Generated Child(final SuperBuilderCustomized.Child.ChildBuilder<?, ?> b) {
       super(b);
       this.field2 = b.field2;
     }
