@@ -4,7 +4,7 @@
   ToStringExplicitIncludeConf() {
     super();
   }
-  public @java.lang.Override @java.lang.SuppressWarnings("all") java.lang.String toString() {
+  public @java.lang.Override @java.lang.SuppressWarnings("all") @lombok.Generated java.lang.String toString() {
     return (("ToStringExplicitIncludeConf(y=" + this.y) + ")");
   }
 }
