@@ -1,6 +1,6 @@
 class UtilityClassInner {
   static final @lombok.experimental.UtilityClass class UtilClass {
-    private @java.lang.SuppressWarnings("all") UtilClass() {
+    private @java.lang.SuppressWarnings("all") @lombok.Generated UtilClass() {
       super();
       throw new java.lang.UnsupportedOperationException("This is a utility class and cannot be instantiated");
     }
@@ -8,4 +8,4 @@ class UtilityClassInner {
   UtilityClassInner() {
     super();
   }
-}
\ No newline at end of file
+}
