@@ -1,3 +1,5 @@
+import java.util.function.Function;
+import java.util.function.Supplier;
 import lombok.val;
 class ValInLambda {
   Runnable foo = (Runnable) () -> {
@@ -24,4 +26,11 @@ class ValInLambda {
 } : System.out::println);
 };
   }
+  public void inParameter() {
+    final @val java.util.function.Function<java.util.function.Supplier<java.lang.String>, java.lang.String> foo = (Function<Supplier<String>, String>) (<no type> s) -> s.get();
+    final @val java.lang.String foo2 = foo.apply(() -> {
+  final @val java.lang.String bar = "";
+  return bar;
+});
+  }
 }
