@@ -4,7 +4,7 @@ class ValueParent {
   }
 }
 final @lombok.Value class ValueCallSuper extends ValueParent {
-  public @java.lang.Override @java.lang.SuppressWarnings("all") boolean equals(final java.lang.Object o) {
+  public @java.lang.Override @java.lang.SuppressWarnings("all") @lombok.Generated boolean equals(final java.lang.Object o) {
     if ((o == this))
         return true;
     if ((! (o instanceof ValueCallSuper)))
@@ -16,17 +16,17 @@ final @lombok.Value class ValueCallSuper extends ValueParent {
         return false;
     return true;
   }
-  protected @java.lang.SuppressWarnings("all") boolean canEqual(final java.lang.Object other) {
+  protected @java.lang.SuppressWarnings("all") @lombok.Generated boolean canEqual(final java.lang.Object other) {
     return (other instanceof ValueCallSuper);
   }
-  public @java.lang.Override @java.lang.SuppressWarnings("all") int hashCode() {
+  public @java.lang.Override @java.lang.SuppressWarnings("all") @lombok.Generated int hashCode() {
     final int result = super.hashCode();
     return result;
   }
-  public @java.lang.Override @java.lang.SuppressWarnings("all") java.lang.String toString() {
+  public @java.lang.Override @java.lang.SuppressWarnings("all") @lombok.Generated java.lang.String toString() {
     return "ValueCallSuper()";
   }
-  public @java.lang.SuppressWarnings("all") ValueCallSuper() {
+  public @java.lang.SuppressWarnings("all") @lombok.Generated ValueCallSuper() {
     super();
   }
 }
