@@ -1,9 +1,9 @@
 final @lombok.Value class ValueWithJavaBeansSpecCapitalization {
   private final int aField;
-  public @java.lang.SuppressWarnings("all") int getaField() {
+  public @java.lang.SuppressWarnings("all") @lombok.Generated int getaField() {
     return this.aField;
   }
-  public @java.lang.Override @java.lang.SuppressWarnings("all") boolean equals(final java.lang.Object o) {
+  public @java.lang.Override @java.lang.SuppressWarnings("all") @lombok.Generated boolean equals(final java.lang.Object o) {
     if ((o == this))
         return true;
     if ((! (o instanceof ValueWithJavaBeansSpecCapitalization)))
@@ -13,16 +13,16 @@ final @lombok.Value class ValueWithJavaBeansSpecCapitalization {
         return false;
     return true;
   }
-  public @java.lang.Override @java.lang.SuppressWarnings("all") int hashCode() {
+  public @java.lang.Override @java.lang.SuppressWarnings("all") @lombok.Generated int hashCode() {
     final int PRIME = 59;
     int result = 1;
     result = ((result * PRIME) + this.getaField());
     return result;
   }
-  public @java.lang.Override @java.lang.SuppressWarnings("all") java.lang.String toString() {
+  public @java.lang.Override @java.lang.SuppressWarnings("all") @lombok.Generated java.lang.String toString() {
     return (("ValueWithJavaBeansSpecCapitalization(aField=" + this.getaField()) + ")");
   }
-  public @java.lang.SuppressWarnings("all") ValueWithJavaBeansSpecCapitalization(final int aField) {
+  public @java.lang.SuppressWarnings("all") @lombok.Generated ValueWithJavaBeansSpecCapitalization(final int aField) {
     super();
     this.aField = aField;
   }
