@@ -3,7 +3,7 @@
 class BuilderInvalidUse {
 	private int something;
 
-	@lombok.Getter @lombok.Setter @lombok.experimental.FieldDefaults(makeFinal = true) @lombok.experimental.Wither @lombok.Data @lombok.ToString @lombok.EqualsAndHashCode
+	@lombok.Getter @lombok.Setter @lombok.experimental.FieldDefaults(makeFinal = true) @lombok.With @lombok.Data @lombok.ToString @lombok.EqualsAndHashCode
 	@lombok.AllArgsConstructor
 	public static class BuilderInvalidUseBuilder {
 
