@@ -1,10 +1,11 @@
 //skip compare content
 //CONF: lombok.Getter.flagUsage = WARNING
 //CONF: lombok.experimental.flagUsage = ERROR
+@lombok.experimental.FieldNameConstants
 public class FlagUsages {
 	@lombok.Getter String x;
 
-	@lombok.experimental.Wither String z;
+	String z;
 
 	public FlagUsages(String x, String y) {
 	}
