@@ -15,4 +15,16 @@ class LoggerLog4jWithDifferentName {
 @Log4j(topic=LoggerLog4jWithStaticField.TOPIC)
 class LoggerLog4jWithStaticField {
 	static final String TOPIC = "StaticField";
+}
+
+@Log4j
+enum LoggerLog4jWithEnum {
+	CONSTANT;
+}
+
+class LoggerLog4jWithInnerEnum {
+	@Log4j
+	enum Inner {
+		CONSTANT;
+	}
 }
\ No newline at end of file
