@@ -10,4 +10,9 @@ class LoggerXSlf4jWithImport {
 
 @XSlf4j(topic="DifferentName")
 class LoggerXSlf4jWithDifferentName {
+}
+
+@XSlf4j(topic=LoggerXSlf4jWithStaticField.TOPIC)
+class LoggerXSlf4jWithStaticField {
+	static final String TOPIC = "StaticField";
 }
\ No newline at end of file
