@@ -1,4 +1,7 @@
-// version 8:
+// version 8:9
+
+import java.util.function.Function;
+import java.util.function.Supplier;
 
 import lombok.val;
 
@@ -25,4 +28,12 @@ class ValInLambda {
             lombok.val fooInner = (System.currentTimeMillis() > 0) ? (Runnable)()-> {} : System.out::println;
         };
     }
+    
+    public void inParameter() {
+        val foo = (Function<Supplier<String>, String>) s -> s.get();
+        val foo2 = foo.apply(() -> {
+            val bar = "";
+            return bar;
+        });
+    }
 }
